#!/usr/bin/env python3
# -*- coding: utf-8 -*-
#
# esphome documentation build configuration file, created by
# sphinx-quickstart on Mon Jan 22 21:44:07 2018.
#
# This file is execfile()d with the current directory set to its
# containing dir.
#
# Note that not all possible configuration values are present in this
# autogenerated file.
#
# All configuration values have a default; values that are commented out
# serve to show the default.

# If extensions (or modules to document with autodoc) are in another directory,
# add these directories to sys.path here. If the directory is relative to the
# documentation root, use os.path.abspath to make it absolute, like shown here.
#
# import os
# import sys
# sys.path.insert(0, os.path.abspath('.'))
import hashlib
import os
import sys


sys.path.append(os.path.abspath("."))

# -- General configuration ------------------------------------------------

# If your documentation needs a minimal Sphinx version, state it here.
#
# needs_sphinx = '1.0'

# Add any Sphinx extension module names here, as strings. They can be
# extensions coming with Sphinx (named 'sphinx.ext.*') or your custom
# ones.
extensions = [
    "github",
    "seo",
    "components",
    "sitemap",
]

# Add any paths that contain templates here, relative to this directory.
templates_path = ["_templates"]

# The suffix(es) of source filenames.
# You can specify multiple suffix as a list of string:
#
# source_suffix = ['.rst', '.md']
source_suffix = ".rst"

# The master toctree document.
master_doc = "index"

# General information about the project.
project = "ESPHome"
copyright = "2022, Nabu Casa"
html_show_copyright = False
html_show_sphinx = False
author = "ESPHome"

# The version info for the project you're documenting, acts as replacement for
# |version| and |release|, also used in various other places throughout the
# built documents.
#
# The short X.Y version.
version = "2024.4"
# The full version, including alpha/beta/rc tags.
release = "2024.4.0b3"

# The language for content autogenerated by Sphinx. Refer to documentation
# for a list of supported languages.
#
# This is also used if you do content translation via gettext catalogs.
# Usually you set "language" from the command line for these cases.
language = "en"

# List of patterns, relative to source directory, that match files and
# directories to ignore when looking for source files.
# This patterns also effect to html_static_path and html_extra_path
exclude_patterns = [
    "_build",
    "Thumbs.db",
    ".DS_Store",
    "env",
    "venv",
    "ENV",
    ".venv",
    ".env",
]

html_extra_path = [
    "_redirects",
]

# The reST default role (used for this markup: `text`) to use for all documents.
# default_role = 'cpp:any'

# The name of the Pygments (syntax highlighting) style to use.
# pygments_style = "xcode"


highlight_language = "yaml"

primary_domain = None

# If true, `todo` and `todoList` produce output, else they produce nothing.
todo_include_todos = False


# -- Options for HTML output ----------------------------------------------

# The theme to use for HTML and HTML Help pages.  See the documentation for
# a list of builtin themes.
#
html_theme = "esphome"
html_theme_path = ["_themes"]

# Theme options are theme-specific and customize the look and feel of a theme
# further.  For a list of options available for each theme, see the
# documentation.
#
html_baseurl = os.getenv("BASE_URL", "https://esphome.io")
with open("_static/custom.css", "rb") as f:
    custom_css_hash = hashlib.md5(f.read()).hexdigest()[:8]

html_theme_options = {
    # 'logo': 'logo-full.png',
    "logo_name": False,
    "show_related": False,
    "sidebar_collapse": True,
    "fixed_sidebar": True,
    "show_powered_by": False,
}

html_context = {
    "custom_css_hash": custom_css_hash,
}

html_logo = "images/logo-text.svg"
html_copy_source = True
html_show_sourcelink = False
html_last_updated_fmt = None
html_use_smartypants = False
html_title = "ESPHome"

# Add any paths that contain custom static files (such as style sheets) here,
# relative to this directory. They are copied after the builtin static files,
# so a file named "default.css" will overwrite the builtin "default.css".
html_static_path = ["_static"]

# Custom sidebar templates, must be a dictionary that maps document names
# to template names.
#
# This is required for the alabaster theme
# refs: http://alabaster.readthedocs.io/en/latest/installation.html#sidebars
html_sidebars = {
    "**": [
        # 'about.html',
        "searchbox.html",
        "localtoc.html",
        "contact.html",
    ]
}


# -- Options for HTMLHelp output ------------------------------------------

# Output file base name for HTML help builder.
htmlhelp_basename = "esphomedoc"


# -- Options for LaTeX output ---------------------------------------------

latex_elements = {
    # The paper size ('letterpaper' or 'a4paper').
    #
    # 'papersize': 'letterpaper',
    # The font size ('10pt', '11pt' or '12pt').
    #
    # 'pointsize': '10pt',
    # Additional stuff for the LaTeX preamble.
    #
    # 'preamble': '',
    # Latex figure (float) alignment
    #
    # 'figure_align': 'htbp',
}

# Grouping the document tree into LaTeX files. List of tuples
# (source start file, target name, title,
#  author, documentclass [howto, manual, or own class]).
latex_documents = [
    (master_doc, "esphome.tex", "ESPHome Documentation", author, "manual"),
]

latex_engine = "xelatex"


# -- Options for manual page output ---------------------------------------

# One entry per manual page. List of tuples
# (source start file, name, description, authors, manual section).
man_pages = [(master_doc, "esphome", "ESPHome Documentation", [author], 1)]


# -- Options for Texinfo output -------------------------------------------

# Grouping the document tree into Texinfo files. List of tuples
# (source start file, target name, title, author,
#  dir menu entry, description, category)
texinfo_documents = [
    (
        master_doc,
        "esphome",
        "ESPHome Documentation",
        author,
        "esphome",
        "One line description of project.",
        "Miscellaneous",
    ),
]
linkcheck_ignore = [r"https://github.com/.*", r"https://discord.gg/.*"]
